MultiSelectUtils class

Constructors

MultiSelectUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

convertItemsToMap(List<Map<String, dynamic>> items, String primaryIdKey) → Map<String, Map<String, dynamic>>
convertMapToList(Map<String, Map<String, dynamic>> itemsMap) → List<Map<String, dynamic>>
getSelectedIds(List<Map<String, dynamic>> selectedItems, String primaryIdKey) → Set<String>